==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/sitesecurityencryption/encryption/encryptionprofile/profile/customerprofile/keytype/DefaultPsk.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.profile.customerprofile.keytype;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.profile.customerprofile.KeyType;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of psk.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultPsk extends InnerModelObject implements Psk {
    protected String presharedKey;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String presharedKey() {
        return presharedKey;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void presharedKey(String presharedKey) {
        valueLeafFlags.set(LeafIdentifier.PRESHAREDKEY.getLeafIndex());
        this.presharedKey = presharedKey;
    }

    @Override
    public int hashCode() {
        return Objects.hash(presharedKey, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultPsk) {
            DefaultPsk other = (DefaultPsk) obj;
            return
                Objects.equals(presharedKey, other.presharedKey) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("presharedKey=" + presharedKey)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultPsk.
     */
    public DefaultPsk() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/sitesecurityencryption/encryption/encryptionprofile/profile/customerprofile/keytype/DefaultPsk.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.profile.customerprofile.keytype;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.profile.customerprofile.KeyType;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of psk.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultPsk extends InnerModelObject implements Psk {
    protected String presharedKey;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String presharedKey() {
        return presharedKey;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void presharedKey(String presharedKey) {
        valueLeafFlags.set(LeafIdentifier.PRESHAREDKEY.getLeafIndex());
        this.presharedKey = presharedKey;
    }

    @Override
    public int hashCode() {
        return Objects.hash(presharedKey, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultPsk) {
            DefaultPsk other = (DefaultPsk) obj;
            return
                Objects.deepEquals(presharedKey, other.presharedKey) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("presharedKey=" + presharedKey)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultPsk.
     */
    public DefaultPsk() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
